Web UI
======

The web UI provides a graphical inspection interface
that covers the most of the telnet commands.

.. versionadded:: 0.6.0

``aiomonitor.webui.app``
------------------------

The main implementation of the aiohttp-based webapp implementation.

.. automodule:: aiomonitor.webui.app
   :members:
   :undoc-members:

``aiomonitor.webui.utils``
--------------------------

It contains a set of utility functions to validate and process the HTTP handler arguments.

.. automodule:: aiomonitor.webui.utils
   :members:
   :undoc-members:
